/* Test 1 of removing a user.
 * $Id$
 * Description: Test OAP DELETE_USER on current user.
 *
 * Authors:
 * Matthew Mundell <matthew.mundell@greenbone.net>
 *
 * Copyright:
 * Copyright (C) 2009 Greenbone Networks GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * or, at your option, any later version as published by the Free
 * Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#define TRACE 1

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "common.h"
#include "../tracef.h"

int
main ()
{
  int socket;
  gnutls_session_t session;
  entity_t entity;
  char *name;

  setup_test ();

  /* Get the user name. */

  name = getenv ("OPENVAS_TEST_USER");
  if (name == NULL)
    {
      name = getenv ("USER");
      if (name == NULL) return EXIT_FAILURE;
    }

  /* Connect and auth as that user. */

  socket = connect_to_manager (&session);
  if (socket == -1) return EXIT_FAILURE;

  if (omp_authenticate_env (&session))
    {
      close_manager_connection (socket, session);
      return EXIT_FAILURE;
    }

  /* Try delete the user. */

  if (openvas_server_sendf (&session,
                            "<delete_user name=\"%s\"/>",
                            name)
      == -1)
    {
      close_manager_connection (socket, session);
      return EXIT_FAILURE;
    }

  entity = NULL;
  if (read_entity (&session, &entity))
    {
      close_manager_connection (socket, session);
      return EXIT_FAILURE;
    }

  /* Check the response. */

  if (entity_attribute (entity, "status")
      && (strcmp (entity_attribute (entity, "status"), "400") == 0))
    {
      free_entity (entity);
      close_manager_connection (socket, session);
      return EXIT_SUCCESS;
    }

  free_entity (entity);
  close_manager_connection (socket, session);
  return EXIT_FAILURE;
}
